netapp_ontap.models.iscsi_service_target API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.iscsi_service_target`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class IscsiServiceTargetSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the IscsiServiceTarget object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `alias GET POST PATCH`

    The iSCSI target alias of the iSCSI service.
    The target alias can contain one (1) to 128 characters and feature any printable character except space (" "). A PATCH request with an empty alias ("") clears the alias.
    Optional in POST and PATCH. In POST, this defaults to the name of the SVM.

    Example: svm1

  `name GET`

    The iSCSI target name of the iSCSI service. This is generated for the SVM during POST.
    If required, the target name can be modified using the ONTAP command line.

    Example: iqn.1992-08.com.netapp:sn.574caf71890911e8a6b7005056b4ea79:vs.2